/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.cbs.ddv.converter;

import dk.sundhedsdatastyrelsen.cbs.dto.impl.vaccination.VaccinationBuilder;
import dk.sundhedsdatastyrelsen.cbs.dto.vaccination.EffectuatedVaccination;
import dk.sundhedsdatastyrelsen.cbs.dto.vaccination.Vaccination;
import dk.vaccinationsregister.schemas._2013._12._01.EffectuationOverviewType;
import dk.vaccinationsregister.schemas._2013._12._01.GetVaccinationPassportAsPDFResponseType;
import dk.vaccinationsregister.schemas._2013._12._01.VaccinationStatus;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.core.convert.converter.Converter;
import org.springframework.lang.NonNull;
import org.springframework.stereotype.Component;

import java.util.Objects;

import static dk.sundhedsdatastyrelsen.cbs.dto.impl.vaccination.VaccinationBuilder.vaccination;

@Component
public class VaccinationConverter implements Converter<GetVaccinationPassportAsPDFResponseType, Vaccination> {

    @NonNull private final Converter<EffectuationOverviewType, EffectuatedVaccination> effectuatedVaccinationConverter;

    @Autowired
    public VaccinationConverter(
        @NonNull final Converter<EffectuationOverviewType, EffectuatedVaccination> effectuatedVaccinationConverter) {
        this.effectuatedVaccinationConverter = effectuatedVaccinationConverter;
    }

    @Override
    @NonNull
    public Vaccination convert(@NonNull final GetVaccinationPassportAsPDFResponseType source) {
        final VaccinationBuilder builder = vaccination(
            source.getPersonInfo().getPersonCivilRegistrationIdentifier(),
            source.getVaccinationStatus() == VaccinationStatus.VACCINERET);
        source.getEffectuation().stream()
            .map(effectuatedVaccinationConverter::convert)
            .filter(Objects::nonNull)
            .forEach(builder::add);
        return builder.build();
    }

}
