/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.cbs.dto.impl.lab;

import com.fasterxml.jackson.annotation.*;
import dk.sundhedsdatastyrelsen.cbs.dto.lab.LabResult;
import dk.sundhedsdatastyrelsen.cbs.dto.lab.LabResults;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.springframework.lang.NonNull;

import java.util.Arrays;
import java.util.HashSet;
import java.util.Set;

@JsonFormat(shape = JsonFormat.Shape.OBJECT)
@JsonIgnoreProperties("empty") //ignore HashSet "isEmpty" property
public class LabResultsImpl extends HashSet<LabResult> implements LabResults {

    private static final String CPR_PROPERTY = "cpr";
    private static final String RESULTS_PROPERTY = "results";
    private final String cpr;

    public LabResultsImpl(String cpr) {
        this.cpr = cpr;
    }

    public LabResultsImpl(String cpr, LabResult... results) {
        super(Arrays.asList(results));
        this.cpr = cpr;
    }

    @JsonCreator
    public LabResultsImpl(@JsonProperty(CPR_PROPERTY) String cpr,
                          @JsonProperty(RESULTS_PROPERTY) Set<LabResult> results) {
        super(results);
        this.cpr = cpr;
    }

    @NonNull
    @Override
    @JsonGetter
    @JsonProperty(CPR_PROPERTY)
    public String cpr() {
        return cpr;
    }

    /**
     * Used by Jackson during serialization
     */
    @NonNull
    @JsonGetter
    @JsonProperty(RESULTS_PROPERTY)
    public Set<LabResult> results() {
        return new HashSet<>(this);
    }


    @Override
    public boolean equals(Object o) {
        if (this == o) return true;

        if (o == null || getClass() != o.getClass()) return false;

        LabResultsImpl that = (LabResultsImpl) o;

        return new EqualsBuilder().appendSuper(super.equals(o)).append(cpr, that.cpr).isEquals();
    }

    @Override
    public int hashCode() {
        return new HashCodeBuilder(17, 37).appendSuper(super.hashCode()).append(cpr).toHashCode();
    }
}
