/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.cbs.dto.impl.vaccination;

import dk.sundhedsdatastyrelsen.cbs.dto.vaccination.EffectuatedVaccination;
import org.springframework.lang.NonNull;
import org.springframework.lang.Nullable;

import java.time.LocalDateTime;

public final class EffectuatedVaccinationBuilder {

    private final long drugIdentifier;
    @NonNull private final String atcCode;
    @NonNull private final String drugName;
    @Nullable private LocalDateTime effectuated;

    private EffectuatedVaccinationBuilder(
        final long drugIdentifier,
        @NonNull final String drugName,
        @NonNull final String atcCode) {
        this.drugIdentifier = drugIdentifier;
        this.drugName = drugName;
        this.atcCode = atcCode;
    }

    @NonNull
    public static EffectuatedVaccinationBuilder effectuatedVaccination(
        final long drugIdentifier,
        @NonNull final String drugName,
        @NonNull final String atcCode) {
        return new EffectuatedVaccinationBuilder(drugIdentifier, drugName, atcCode);
    }

    @NonNull
    public EffectuatedVaccinationBuilder effectuated(@Nullable final LocalDateTime effectuated) {
        this.effectuated = effectuated;
        return this;
    }


    @NonNull
    public EffectuatedVaccination build() {
        return new EffectuatedVaccinationImpl(
            drugIdentifier,
            atcCode,
            drugName,
            effectuated);

    }
}
