/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.cbs.test;

import dk.sds.nsp.kafka.clients.producer.NSPKafkaProducer;
import dk.sds.nsp.security.SecurityContext;
import dk.sundhedsdatastyrelsen.cbs.dto.kafka.DataFetcherJob;
import dk.sundhedsdatastyrelsen.cbs.dto.kafka.JobType;
import dk.sundhedsdatastyrelsen.cbs.mocks.MockDataService;
import dk.sundhedsdatastyrelsen.cbs.service.Service;
import dk.sundhedsdatastyrelsen.cbs.service.security.Security;
import dk.sundhedsdatastyrelsen.coronapass._2021._03.coronapass_web_service.GetCoronaPassRequest;
import org.mockito.Mockito;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;
import org.springframework.context.annotation.PropertySource;
import org.springframework.lang.NonNull;

import java.util.Properties;
import java.util.UUID;
import java.util.function.Function;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.ArgumentMatchers.anyString;
import static org.mockito.Mockito.mock;

@Configuration
@PropertySource("classpath:unittest.properties")
public class TestConfiguration {

    @Primary
    @Bean
    public Service service() {
        Service mockService = mock(Service.class);
        Mockito.lenient().when(mockService.createDataFetcherJob(anyString(), anyString(), any(JobType.class))).thenAnswer(i -> UUID.randomUUID().toString());
        return mockService;
    }

    @Bean
    public MockDataService mockDataService(Service service) {
        return new MockDataService(service);
    }

    @Bean
    public Security mockSecurity() {
        return new Security() {
            @NonNull
            @Override
            public String checkSecurityTicketGetCpr(@NonNull SecurityContext securityContext, @NonNull GetCoronaPassRequest request) {
                return request.getIdentifier();
            }
        };
    }

    @Bean
    public Function<Properties, NSPKafkaProducer<String, DataFetcherJob>> nspKafkaProducerConstructor() {
        return Mockito.mock(Function.class);
    }
}
