/*
 * The MIT License
 *
 * Original work sponsored and donated by The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 * Copyright (C) 2021 The Danish Health Data Authority (http://www.sundhedsdatastyrelsen.dk)
 *
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of
 * this software and associated documentation files (the "Software"), to deal in
 * the Software without restriction, including without limitation the rights to
 * use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do
 * so, subject to the following conditions:
 *
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sundhedsdatastyrelsen.cbs.kids.config;

import dk.sundhedsdatastyrelsen.cbs.datacache.Reader;
import dk.sundhedsdatastyrelsen.cbs.datacache.impl.Readers;
import dk.sundhedsdatastyrelsen.cbs.kids.dao.KidsLabResult;
import dk.sundhedsdatastyrelsen.cbs.kids.dao.KidsLabResultImpl;
import dk.sundhedsdatastyrelsen.cbs.kids.dao.KidsMappers;
import dk.sundhedsdatastyrelsen.fluent.spring.jdbc.SearchMapper;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.jdbc.datasource.DriverManagerDataSource;
import org.springframework.lang.NonNull;

import javax.sql.DataSource;
import java.util.Collection;

@Configuration
public class KidsConfiguration {
    @Value("${kids.datasource.driver}")
    private String driverClassName;

    @Value("${kids.datasource.url}")
    private String url;

    @Value("${kids.datasource.username}")
    private String username;

    @Value("${kids.datasource.password}")
    private String password;


    @Bean
    @NonNull
    public Reader<Collection<KidsLabResult>, String> reader(
        @NonNull @Kids final DataSource dataSource,
        @NonNull final SearchMapper<KidsLabResultImpl, String> mapper) {
        return Readers.reader(dataSource, mapper);
    }

    @Bean
    @NonNull
    public SearchMapper<KidsLabResultImpl, String> mapper() {
        return KidsMappers.mapper();
    }

    @Kids
    @Bean
    public DataSource kidsDataSource() {
        DriverManagerDataSource dataSource = new DriverManagerDataSource();
        dataSource.setDriverClassName(driverClassName);
        dataSource.setUrl(url);
        dataSource.setUsername(username);
        dataSource.setPassword(password);
        return dataSource;
    }

}
